@@ -644,6 +644,12 @@ func (c *OAuthServerConfig) getAuthenticationRequestHandler() (authenticator.Req
 						return nil, fmt.Errorf("Error loading certs from %s: %v", provider.ClientCA, err)
 					}
 
+					// we need to add our CA data to secure serving as well to have the OAuth server
+					// advertise them for client auth during TLS handshake
+					if ok := c.GenericConfig.SecureServing.ClientCA.AppendCertsFromPEM(caData); !ok {
+						return nil, fmt.Errorf("error adding certs from %s to secureServing: %v", provider.ClientCA, err)
+					}
+
 					authRequestHandler = x509request.NewVerifier(opts, authRequestHandler, sets.NewString(provider.ClientCommonNames...))
 				}
 				authRequestHandlers = append(authRequestHandlers, authRequestHandler)
